#
# Disaster Monitoring Constellation (DMC)
#
# see http://www.dmcii.com/
#
# Five satellites. Four spaced equally in a sun-synchronous plane, which
# ascends over Equator at 10:15 am
# in order after each other: Alsat-1, NigeriaSat-1, BILSAT-1, UK-DMC.
#
# The fifth satellite, Beijing-1, is in a separate plane which
# ascends over Equator at 10:30am, i.e. 360/24/4 = 3.75 degrees west.
#
# Orbital details from a presentation on the DMC and its capabilities,
# David Hodgson, 11th Conference on Control with Remote Sensing of
# Area-based Subsidies, Krakow, Poland, 25 November 2005 (slide 5).
#
# $Id: dmc.tcl,v 1.2 2006/07/08 20:07:47 lloydwood Exp $

set a [expr 686.0+$RADIUS_OF_EARTH]

set inc 98.2
set e 0.0
set omega 0.0
set Omega 0.0

# 0 or 5 degrees would be minimum for ground station visibility.
# To get an idea of 600km swath width under DMC satellite,
# arctan(686/300) = 66.4 degrees.

set coverage_angle 66.4

puts stderr "\n\nSaVi: coverage angle of $coverage_angle deg intended to give extent of DMC imaging swath."
puts stderr "      set coverage angle to zero for limits of communications connectivity."

set SATS_PER_PLANE 4

# compute period of orbit
set T_per [expr 2 * $PI * pow($a,1.5) / sqrt($MU)]

satellites GV_BEGIN

for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
    set T [expr $T_per / $SATS_PER_PLANE * $i ]
    satellites LOAD $a $e $inc $Omega $omega $T
}

set Omega 3.75

# optimum intermediate spacing would interleave the satellite with
# the other plane; Beijing-1 likely isn't this well-spaced.

set T [expr $T_per / $SATS_PER_PLANE /2 ]

satellites LOAD $a $e $inc $Omega $omega $T

satellites GV_END
